@@ -24,6 +24,8 @@ import (
 	"sync"
 	"time"
 
+	"github.com/bep/godartsass"
+	"github.com/gohugoio/hugo/common/hexec"
 	"github.com/gohugoio/hugo/hugofs/files"
 
 	"github.com/spf13/afero"
@@ -184,24 +186,15 @@ func getBuildInfo() *buildInfo {
 	return bInfo
 }
 
+func formatDep(path, version string) string {
+	return fmt.Sprintf("%s=%q", path, version)
+}
+
 // GetDependencyList returns a sorted dependency list on the format package="version".
 // It includes both Go dependencies and (a manually maintained) list of C(++) dependencies.
 func GetDependencyList() []string {
 	var deps []string
 
-	formatDep := func(path, version string) string {
-		return fmt.Sprintf("%s=%q", path, version)
-	}
-
-	if IsExtended {
-		deps = append(
-			deps,
-			// TODO(bep) consider adding a DepsNonGo() method to these upstream projects.
-			formatDep("github.com/sass/libsass", "3.6.5"),
-			formatDep("github.com/webmproject/libwebp", "v1.2.4"),
-		)
-	}
-
 	bi := getBuildInfo()
 	if bi == nil {
 		return deps
@@ -211,11 +204,36 @@ func GetDependencyList() []string {
 		deps = append(deps, formatDep(dep.Path, dep.Version))
 	}
 
+	deps = append(deps, GetDependencyListNonGo()...)
+
 	sort.Strings(deps)
 
 	return deps
 }
 
+// GetDependencyListNonGo returns a list of non-Go dependencies.
+func GetDependencyListNonGo() []string {
+	var deps []string
+
+	if IsExtended {
+		deps = append(
+			deps,
+			formatDep("github.com/sass/libsass", "3.6.5"),
+			formatDep("github.com/webmproject/libwebp", "v1.2.4"),
+		)
+	}
+
+	if dartSass := dartSassVersion(); dartSass.ProtocolVersion != "" {
+		const dartSassPath = "github.com/sass/dart-sass-embedded"
+		deps = append(deps,
+			formatDep(dartSassPath+"/protocol", dartSass.ProtocolVersion),
+			formatDep(dartSassPath+"/compiler", dartSass.CompilerVersion),
+			formatDep(dartSassPath+"/implementation", dartSass.ImplementationVersion),
+		)
+	}
+	return deps
+}
+
 // IsRunningAsTest reports whether we are running as a test.
 func IsRunningAsTest() bool {
 	for _, arg := range os.Args {
@@ -249,3 +267,13 @@ type Dependency struct {
 	// Replaced by this dependency.
 	Replace *Dependency
 }
+
+func dartSassVersion() godartsass.DartSassVersion {
+	// This is also duplicated in the dartsass package.
+	const dartSassEmbeddedBinaryName = "dart-sass-embedded"
+	if !hexec.InPath(dartSassEmbeddedBinaryName) {
+		return godartsass.DartSassVersion{}
+	}
+	v, _ := godartsass.Version(dartSassEmbeddedBinaryName)
+	return v
+}
