@@ -268,7 +268,10 @@ func (p *pageState) Pages() page.Pages {
 		case page.KindSection, page.KindHome:
 			pages = p.getPagesAndSections()
 		case page.KindTerm:
-			pages = p.bucket.getTaxonomyEntries()
+			b := p.treeRef.n
+			viewInfo := b.viewInfo
+			taxonomy := p.s.Taxonomies()[viewInfo.name.plural].Get(viewInfo.termKey)
+			pages = taxonomy.Pages()
 		case page.KindTaxonomy:
 			pages = p.bucket.getTaxonomies()
 		default:
